package de.hftstuttgart.unifiedticketing.systems.gitlab;

import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.junit.jupiter.api.Test;

import java.io.IOException;

import static org.junit.jupiter.api.Assertions.*;

public class GitlabTicketResponseTest
{
    @Test
    public void testDeserialization() throws IOException
    {
        ObjectMapper mapper = new ObjectMapper()
            .configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
        String[] values = new String[]
            // title                descr       iid     label   label           userid  user full-/username
            {"title of ticket", "description", "5", "bug", "unifiedticketing", "234", "Full name", "username"};
        String responseJson = String.format(
            "{\"title\":\"%s\",\"description\":\"%s\",\"iid\":%s," +
                "\"labels\":[\"%s\",\"%s\"],\"assignees\":[{\"id\":%s,\"name\":\"%s\",\"username\":\"%s\"}]}",
            (Object[]) values);

        GitlabTicketResponse response = mapper.readValue(responseJson.getBytes(), GitlabTicketResponse.class);
        assertAll(
            () -> assertEquals(values[0], response.title),
            () -> assertEquals(values[1], response.description),
            () -> assertEquals(values[2], String.valueOf(response.iid)),
            () -> assertTrue(response.labels.contains(values[3])),
            () -> assertTrue(response.labels.contains(values[4])),
            () -> assertEquals(1, response.assignees.size()),
            () -> assertEquals(values[5], String.valueOf(response.assignees.get(0).id)),
            () -> assertEquals(values[6], response.assignees.get(0).name),
            () -> assertEquals(values[7], response.assignees.get(0).username)
        );
    }
}
